1. First item
2. Second item
3. Third item
    1. Indented item
    2. Indented item
4. Fourth item

1. First item
8. Second item
3. Third item
5. Fourth item

- 1968\. A great year!
- I think 1969 was second best.

Without blank lines, this would be a heading.
---
Don't do this!

[link](https://www.example.com/my great page)

#### Heading level 4

This **word** is bold. This <em>word</em> is italic.

| Syntax      | Description | Test Text     |
| :---        |    :----:   |          --:-: |
| Header      | Title       | Here's this   |
| Paragraph   | Text        | And more      |

| Syntax      | Description | Test Text     |
| :---        |    :----:   |          ---: |
| Header      | Title       | Here's this   |
| Paragraph   | Text        | And more      |

{
  "firstName": "John",
  "lastName": "Smith",
  "age": 25
}
```